==> pixelpay_sdk-2.0.3.tar.gz: android/src/main/java/com/pixel/flutter/sdk/pixelpay_sdk/PixelpaySdkPlugin.java <==
package com.pixel.flutter.sdk.pixelpay_sdk;

import android.app.Activity;

import androidx.annotation.NonNull;

import com.pixel.sdk.base.Helpers;
import com.pixel.sdk.base.Response;
import com.pixel.sdk.mobile.services.Tokenization;
import com.pixel.sdk.mobile.services.Transaction;
import com.pixel.sdk.models.Settings;
import com.pixel.sdk.requests.AuthTransaction;
import com.pixel.sdk.requests.CaptureTransaction;
import com.pixel.sdk.requests.CardTokenization;
import com.pixel.sdk.requests.SaleTransaction;
import com.pixel.sdk.requests.StatusTransaction;
import com.pixel.sdk.requests.VoidTransaction;

import java.util.HashMap;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** PixelpaySdkPlugin */
public class PixelpaySdkPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /**
   * The MethodChannel that will the communication between Flutter and native Android
   */
  private MethodChannel channel;

  /**
   * FlutterActivity
   */
  private Activity activity;

  /**
   * SDK Identifier for request
   */
  private static final String SDK_ID = "sdk-flutter";

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "pixelpay_sdk");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    try {
      switch(call.method) {
        /**
         * Transaction service
         */
        case "transactionDoSale": this.transactionDoSale(call, result); break;
        case "transactionDoAuth": this.transactionDoAuth(call, result); break;
        case "transactionDoCapture": this.transactionDoCapture(call, result); break;
        case "transactionDoVoid": this.transactionDoVoid(call, result); break;
        case "transactionGetStatus": this.transactionGetStatus(call, result); break;

        /**
         * Tokenization service
         */
        case "tokenizationVaultCard": this.tokenizationVaultCard(call, result); break;
        case "tokenizationUpdateCard": this.tokenizationUpdateCard(call, result); break;
        case "tokenizationShowCard": this.tokenizationShowCard(call, result); break;
        case "tokenizationShowCards": this.tokenizationShowCards(call, result); break;
        case "tokenizationDeleteCard": this.tokenizationDeleteCard(call, result); break;

        default: result.notImplemented(); break;
      }
    } catch (Exception ex) {
      this.parseError(result, ex, "exception");
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    this.activity = binding.getActivity();
  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    this.activity = binding.getActivity();
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
  }

  @Override
  public void onDetachedFromActivity() {
  }

  private Settings buildSettings(String settings) {
    final Settings model = Helpers.jsonToObject(settings, Settings.class);
    model.sdk = PixelpaySdkPlugin.SDK_ID;

    return model;
  }

  private Transaction getTransactionService(String settings) {
    return (new Transaction(this.buildSettings(settings), this.activity));
  }

  private Tokenization getTokenizationService(String settings) {
    return (new Tokenization(this.buildSettings(settings), this.activity));
  }

  private void parseSuccess(@NonNull Result result, Response response) {
    Map<String, String> map = new HashMap<>();

    map.put("status", String.valueOf(response.getStatus()));
    map.put("response", response.toJson());

    result.success(map);
  }

  private void parseError(@NonNull Result result, Exception error, String code) {
	result.error(code, error.getLocalizedMessage(), error.getStackTrace());
  }

  private void transactionDoSale(@NonNull MethodCall call, @NonNull Result result) {
    this.getTransactionService(call.argument("settings"))
            .doSale(Helpers.jsonToObject(call.argument("request"), SaleTransaction.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err -> this.parseError(result, err, "transaction-error"))
            .start();
  }

  private void transactionDoAuth(@NonNull MethodCall call, @NonNull Result result) {
    this.getTransactionService(call.argument("settings"))
            .doAuth(Helpers.jsonToObject(call.argument("request"), AuthTransaction.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err -> this.parseError(result, err, "transaction-error"))
            .start();
  }

  private void transactionDoCapture(@NonNull MethodCall call, @NonNull Result result) {
    this.getTransactionService(call.argument("settings"))
            .doCapture(Helpers.jsonToObject(call.argument("request"), CaptureTransaction.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err -> this.parseError(result, err, "transaction-error"))
            .start();
  }

  private void transactionDoVoid(@NonNull MethodCall call, @NonNull Result result) {
    this.getTransactionService(call.argument("settings"))
            .doVoid(Helpers.jsonToObject(call.argument("request"), VoidTransaction.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err -> this.parseError(result, err, "transaction-error"))
            .start();
  }

  private void transactionGetStatus(@NonNull MethodCall call, @NonNull Result result) {
    this.getTransactionService(call.argument("settings"))
            .getStatus(Helpers.jsonToObject(call.argument("request"), StatusTransaction.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err -> this.parseError(result, err, "transaction-error"))
            .start();
  }

  private void tokenizationVaultCard(@NonNull MethodCall call, @NonNull Result result) {
    this.getTokenizationService(call.argument("settings"))
            .vaultCard(Helpers.jsonToObject(call.argument("request"), CardTokenization.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err ->  this.parseError(result, err, "tokenization-error"))
            .start();
  }

  private void tokenizationUpdateCard(@NonNull MethodCall call, @NonNull Result result) {
    this.getTokenizationService(call.argument("settings"))
            .updateCard(call.argument("token"), Helpers.jsonToObject(call.argument("request"), CardTokenization.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err ->  this.parseError(result, err, "tokenization-error"))
            .start();
  }

  private void tokenizationShowCard(@NonNull MethodCall call, @NonNull Result result) {
    this.getTokenizationService(call.argument("settings"))
            .showCard(call.argument("token"))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err ->  this.parseError(result, err, "tokenization-error"))
            .start();
  }

  public void tokenizationShowCards(@NonNull MethodCall call, @NonNull Result result) {
    this.getTokenizationService(call.argument("settings"))
            .showCards(call.argument("tokens"))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err ->  this.parseError(result, err, "tokenization-error"))
            .start();
  }

  public void tokenizationDeleteCard(@NonNull MethodCall call, @NonNull Result result) {
    this.getTokenizationService(call.argument("settings"))
            .deleteCard(call.argument("token"))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err ->  this.parseError(result, err, "tokenization-error"))
            .start();
  }
}

==> pixelpay_sdk-2.0.4.tar.gz: android/src/main/java/com/pixel/flutter/sdk/pixelpay_sdk/PixelpaySdkPlugin.java <==
package com.pixel.flutter.sdk.pixelpay_sdk;

import android.app.Activity;

import androidx.annotation.NonNull;

import com.pixel.sdk.base.Helpers;
import com.pixel.sdk.base.Response;
import com.pixel.sdk.mobile.services.Tokenization;
import com.pixel.sdk.mobile.services.Transaction;
import com.pixel.sdk.models.Settings;
import com.pixel.sdk.requests.AuthTransaction;
import com.pixel.sdk.requests.CaptureTransaction;
import com.pixel.sdk.requests.CardTokenization;
import com.pixel.sdk.requests.SaleTransaction;
import com.pixel.sdk.requests.StatusTransaction;
import com.pixel.sdk.requests.VoidTransaction;

import java.util.HashMap;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** PixelpaySdkPlugin */
public class PixelpaySdkPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /**
   * The MethodChannel that will the communication between Flutter and native Android
   */
  private MethodChannel channel;

  /**
   * FlutterActivity
   */
  private Activity activity;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "pixelpay_sdk");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    try {
      switch(call.method) {
        /**
         * Transaction service
         */
        case "transactionDoSale": this.transactionDoSale(call, result); break;
        case "transactionDoAuth": this.transactionDoAuth(call, result); break;
        case "transactionDoCapture": this.transactionDoCapture(call, result); break;
        case "transactionDoVoid": this.transactionDoVoid(call, result); break;
        case "transactionGetStatus": this.transactionGetStatus(call, result); break;

        /**
         * Tokenization service
         */
        case "tokenizationVaultCard": this.tokenizationVaultCard(call, result); break;
        case "tokenizationUpdateCard": this.tokenizationUpdateCard(call, result); break;
        case "tokenizationShowCard": this.tokenizationShowCard(call, result); break;
        case "tokenizationShowCards": this.tokenizationShowCards(call, result); break;
        case "tokenizationDeleteCard": this.tokenizationDeleteCard(call, result); break;

        default: result.notImplemented(); break;
      }
    } catch (Exception ex) {
      this.parseError(result, ex, "exception");
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    this.activity = binding.getActivity();
  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    this.activity = binding.getActivity();
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
  }

  @Override
  public void onDetachedFromActivity() {
  }

  private Transaction getTransactionService(String settings) {
    return (new Transaction(Helpers.jsonToObject(settings, Settings.class), this.activity));
  }

  private Tokenization getTokenizationService(String settings) {
    return (new Tokenization(Helpers.jsonToObject(settings, Settings.class), this.activity));
  }

  private void parseSuccess(@NonNull Result result, Response response) {
    Map<String, String> map = new HashMap<>();

    map.put("status", String.valueOf(response.getStatus()));
    map.put("response", response.toJson());

    result.success(map);
  }

  private void parseError(@NonNull Result result, Exception error, String code) {
    Response response = new Response();
    Map<String, String> map = new HashMap<>();

    response.setStatus(500);
    response.success = false;
    response.message = error.getLocalizedMessage();

    map.put("status", String.valueOf(response.getStatus()));
    map.put("response", response.toJson());

    result.success(map);
  }

  private void transactionDoSale(@NonNull MethodCall call, @NonNull Result result) {
    this.getTransactionService(call.argument("settings"))
            .doSale(Helpers.jsonToObject(call.argument("request"), SaleTransaction.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err -> this.parseError(result, err, "transaction-error"))
            .start();
  }

  private void transactionDoAuth(@NonNull MethodCall call, @NonNull Result result) {
    this.getTransactionService(call.argument("settings"))
            .doAuth(Helpers.jsonToObject(call.argument("request"), AuthTransaction.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err -> this.parseError(result, err, "transaction-error"))
            .start();
  }

  private void transactionDoCapture(@NonNull MethodCall call, @NonNull Result result) {
    this.getTransactionService(call.argument("settings"))
            .doCapture(Helpers.jsonToObject(call.argument("request"), CaptureTransaction.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err -> this.parseError(result, err, "transaction-error"))
            .start();
  }

  private void transactionDoVoid(@NonNull MethodCall call, @NonNull Result result) {
    this.getTransactionService(call.argument("settings"))
            .doVoid(Helpers.jsonToObject(call.argument("request"), VoidTransaction.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err -> this.parseError(result, err, "transaction-error"))
            .start();
  }

  private void transactionGetStatus(@NonNull MethodCall call, @NonNull Result result) {
    this.getTransactionService(call.argument("settings"))
            .getStatus(Helpers.jsonToObject(call.argument("request"), StatusTransaction.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err -> this.parseError(result, err, "transaction-error"))
            .start();
  }

  private void tokenizationVaultCard(@NonNull MethodCall call, @NonNull Result result) {
    this.getTokenizationService(call.argument("settings"))
            .vaultCard(Helpers.jsonToObject(call.argument("request"), CardTokenization.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err ->  this.parseError(result, err, "tokenization-error"))
            .start();
  }

  private void tokenizationUpdateCard(@NonNull MethodCall call, @NonNull Result result) {
    this.getTokenizationService(call.argument("settings"))
            .updateCard(call.argument("token"), Helpers.jsonToObject(call.argument("request"), CardTokenization.class))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err ->  this.parseError(result, err, "tokenization-error"))
            .start();
  }

  private void tokenizationShowCard(@NonNull MethodCall call, @NonNull Result result) {
    this.getTokenizationService(call.argument("settings"))
            .showCard(call.argument("token"))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err ->  this.parseError(result, err, "tokenization-error"))
            .start();
  }

  public void tokenizationShowCards(@NonNull MethodCall call, @NonNull Result result) {
    this.getTokenizationService(call.argument("settings"))
            .showCards(call.argument("tokens"))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err ->  this.parseError(result, err, "tokenization-error"))
            .start();
  }

  public void tokenizationDeleteCard(@NonNull MethodCall call, @NonNull Result result) {
    this.getTokenizationService(call.argument("settings"))
            .deleteCard(call.argument("token"))
            .then(response -> this.parseSuccess(result, response))
            .thenCatch(err ->  this.parseError(result, err, "tokenization-error"))
            .start();
  }
}
